pub enum DefaultType {
Required,
Optional,
Default(SerializationModel),
}Expand description
Describes whether a field is required or optional
Variants
Required
The field must be supplied
Optional
The field can be supplied, the type of the field will be Option<data_type>, if not supplied it defaults to None
Default(SerializationModel)
The field can be supplied, if not supplied it defaults to the default value