pub enum ErrorCore {
Show 14 variants
UnknownID(String),
UnknownType(String),
EnheritStruct(String),
SerializationModel(SerializationModel, String),
BoolConversion(String),
IntegerConversion(String),
FloatConversion(String),
EnumConversion(String),
TypedEnumConversion(HashMap<String, SerializationModel>),
TypedEnumLayout(HashMap<String, SerializationModel>),
VariantConversion(SerializationModel, Vec<(String, Error)>),
StructConversionMissingField(HashMap<String, SerializationModel>, String),
StructConversionExcessFields(HashMap<String, SerializationModel>),
MacroError(Error),
}Expand description
Errors for when converting generic data models into JSON schema data models
Variants
UnknownID(String)
Unable to find the type id
UnknownType(String)
The type is neither a builtin type or a custom type
EnheritStruct(String)
The type must be a struct
SerializationModel(SerializationModel, String)
Serialization model has an incompatible type
BoolConversion(String)
Unable to convert to boolean
IntegerConversion(String)
Unable to convert to integer
FloatConversion(String)
Unable to convert to float
EnumConversion(String)
Unable to convert to enum
TypedEnumConversion(HashMap<String, SerializationModel>)
Unable to convert to typed enum
TypedEnumLayout(HashMap<String, SerializationModel>)
The map had more or less than one element when converting to a typed enum
VariantConversion(SerializationModel, Vec<(String, Error)>)
Unable to convert to variant
StructConversionMissingField(HashMap<String, SerializationModel>, String)
Unable to convert to struct due to missing field
StructConversionExcessFields(HashMap<String, SerializationModel>)
Unable to convert to struct due to excess fields
MacroError(Error)
Error expanding macros