pub struct ConstrainedType {
pub data_type: String,
pub constraints: Vec<Constraint>,
}Expand description
A constrained type, wraps any other type and adds constraints onto them
Fields
data_type: StringThe type that is constrained
constraints: Vec<Constraint>All extra constraints for the type, must be written as an expression where the constrained value is denoted x
Implementations
Sourceimpl ConstrainedType
impl ConstrainedType
Sourcepub fn export_schema(
&self,
custom_types: &HashMap<String, DataType>,
dependencies: &mut HashSet<String>,
) -> Result<Object, Error>
pub fn export_schema( &self, custom_types: &HashMap<String, DataType>, dependencies: &mut HashSet<String>, ) -> Result<Object, Error>
Creates a JSON schema from the constrained type
Parameters
custom_types: The map of all the custom types, used to check if a type is builtin or not
dependencies: A set to add all dependencies of this constrained type to
Sourcepub fn schema_value(
&self,
value: &SerializationModel,
custom_types: &HashMap<String, DataType>,
) -> Result<JsonValue, Error>
pub fn schema_value( &self, value: &SerializationModel, custom_types: &HashMap<String, DataType>, ) -> Result<JsonValue, Error>
Converts a serialization model value into a JSON value of the for of this type
Parameters
value: The serialization model to convert
custom_types: All the custom types in the schema