pub struct Enum {
pub types: Vec<EnumType>,
}Expand description
An enum, includes a number of enum values
Fields
types: Vec<EnumType>All the possible enum values
Implementations
Sourceimpl Enum
impl Enum
Sourcepub fn export_schema(
&self,
custom_types: &HashMap<String, DataType>,
dependencies: &mut HashSet<String>,
) -> Result<Object, Error>
pub fn export_schema( &self, custom_types: &HashMap<String, DataType>, dependencies: &mut HashSet<String>, ) -> Result<Object, Error>
Creates a JSON schema from the enum
Parameters
custom_types: The map of all the custom types, used to check if a type is builtin or not
dependencies: A set to add all dependencies of this enum to
Sourcepub fn schema_value(
&self,
value: &SerializationModel,
custom_types: &HashMap<String, DataType>,
) -> Result<JsonValue, Error>
pub fn schema_value( &self, value: &SerializationModel, custom_types: &HashMap<String, DataType>, ) -> Result<JsonValue, Error>
Converts a serialization model value into a JSON value of the for of this type
Parameters
value: The serialization model to convert
custom_types: All the custom types in the schema